.. pwman3 documentation master file, created by
   sphinx-quickstart on Wed Dec 17 19:38:24 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pwman3's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2
    
   install
   tutorial
   configuration  
   packaging

About pwman3:
^^^^^^^^^^^^^ 

Pwman3 is a command line password manager for Python3 with support for 
multiple databases.




